@@ -1,6 +1,6 @@
 from abc import abstractmethod
 
-from checkov.arm.registry import arm_registry
+from checkov.arm.registry import arm_resource_registry
 from checkov.common.checks.base_check import BaseCheck
 from checkov.common.multi_signature import multi_signature
 
@@ -10,7 +10,7 @@ class BaseResourceCheck(BaseCheck):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_resources,
                          block_type="resource")
         self.supported_resources = supported_resources
-        arm_registry.register(self)
+        arm_resource_registry.register(self)
 
     def scan_entity_conf(self, conf, entity_type):
         return self.scan_resource_conf(conf, entity_type)
