@@ -4,7 +4,6 @@ import boto3
 import dpath.util
 import json
 import logging
-import os
 import re
 import requests
 import urllib3
@@ -18,10 +17,13 @@ from termcolor import colored
 from tqdm import trange
 from urllib3.exceptions import HTTPError
 
+from checkov.common.bridgecrew.ci_variables import *
 from checkov.common.bridgecrew.platform_errors import BridgecrewAuthError
 from checkov.common.bridgecrew.platform_key import read_key, persist_key, bridgecrew_file
+from checkov.common.bridgecrew.wrapper import reduce_scan_reports, persist_checks_results, \
+    enrich_and_persist_checks_metadata
 from checkov.common.models.consts import SUPPORTED_FILE_EXTENSIONS
-from .wrapper import reduce_scan_reports, persist_checks_results, enrich_and_persist_checks_metadata
+from checkov.version import version as checkov_version
 
 EMAIL_PATTERN = "[^@]+@[^@]+\.[^@]+"
 
@@ -39,12 +41,6 @@ SIGNUP_HEADER = {
     'Content-Type': 'application/json;charset=UTF-8'
 }
 
-try:
-    http = urllib3.ProxyManager(os.environ['https_proxy'])
-except KeyError:
-    http = urllib3.PoolManager()
-
-
 class BcPlatformIntegration(object):
     def __init__(self):
         self.bc_api_key = read_key()
@@ -53,49 +49,94 @@ class BcPlatformIntegration(object):
         self.credentials = None
         self.repo_path = None
         self.repo_id = None
+        self.skip_fixes = False
+        self.skip_suppressions = False
         self.timestamp = None
         self.scan_reports = []
         self.bc_api_url = os.getenv('BC_API_URL', "https://www.bridgecrew.cloud/api/v1")
-        self.bc_source = os.getenv('BC_SOURCE', "cli")
+        self.bc_source = os.getenv('BC_SOURCE', 'cli')
+        self.bc_source_version = None
         self.integrations_api_url = f"{self.bc_api_url}/integrations/types/checkov"
         self.guidelines_api_url = f"{self.bc_api_url}/guidelines"
         self.onboarding_url = f"{self.bc_api_url}/signup/checkov"
         self.api_token_url = f"{self.bc_api_url}/integrations/apiToken"
+        self.suppressions_url = f"{self.bc_api_url}/suppressions"
+        self.fixes_url = f"{self.bc_api_url}/fixes/checkov"
         self.guidelines = None
         self.bc_id_mapping = None
+        self.ckv_to_bc_id_mapping = None
+        self.use_s3_integration = False
+        self.platform_integration_configured = False
+        self.http = None
 
-    def setup_bridgecrew_credentials(self, bc_api_key, repo_id):
+    def setup_http_manager(self, ca_certificate=os.getenv('BC_CA_BUNDLE', None)):
+        """
+        bridgecrew uses both the urllib3 and requests libraries, while checkov uses the requests library.
+        :param ca_certificate: an optional CA bundle to be used by both libraries.
+        """
+        if self.http:
+            return
+        if ca_certificate:
+            os.environ['REQUESTS_CA_BUNDLE'] = ca_certificate
+            try:
+                self.http = urllib3.ProxyManager(os.environ['https_proxy'], cert_reqs='REQUIRED', ca_certs=ca_certificate)
+            except KeyError:
+                self.http = urllib3.PoolManager(cert_reqs='REQUIRED', ca_certs=ca_certificate)
+        else:
+            try:
+                self.http = urllib3.ProxyManager(os.environ['https_proxy'])
+            except KeyError:
+                self.http = urllib3.PoolManager()
+
+    def setup_bridgecrew_credentials(self, bc_api_key, repo_id, skip_fixes=False, skip_suppressions=False, source=None,
+                                     source_version=None):
         """
         Setup credentials against Bridgecrew's platform.
+        :param skip_fixes: whether to skip querying fixes from Bridgecrew
         :param repo_id: Identity string of the scanned repository, of the form <repo_owner>/<repo_name>
         :param bc_api_key: Bridgecrew issued API key
         """
         self.bc_api_key = bc_api_key
         self.repo_id = repo_id
-        try:
-            repo_full_path, response = self.get_s3_role(bc_api_key, repo_id)
-            self.bucket, self.repo_path = repo_full_path.split("/", 1)
-            self.timestamp = self.repo_path.split("/")[-1]
-            self.credentials = response["creds"]
-            self.s3_client = boto3.client("s3",
-                                          aws_access_key_id=self.credentials["AccessKeyId"],
-                                          aws_secret_access_key=self.credentials["SecretAccessKey"],
-                                          aws_session_token=self.credentials["SessionToken"],
-                                          region_name=DEFAULT_REGION
-                                          )
-            sleep(10)  # Wait for the policy to update
-        except HTTPError as e:
-            logging.error(f"Failed to get customer assumed role\n{e}")
-            raise e
-        except ClientError as e:
-            logging.error(f"Failed to initiate client with credentials {self.credentials}\n{e}")
-            raise e
-        except JSONDecodeError as e:
-            logging.error(f"Response of {self.integrations_api_url} is not a valid JSON\n{e}")
-            raise e
+        self.skip_fixes = skip_fixes
+        self.skip_suppressions = skip_suppressions
+        if source:
+            self.bc_source = source
+        if source_version:
+            self.bc_source_version = source_version
+
+        if self.bc_source != 'vscode':
+            try:
+                self.skip_fixes = True  # no need to run fixes on CI integration
+                repo_full_path, response = self.get_s3_role(bc_api_key, repo_id)
+                self.bucket, self.repo_path = repo_full_path.split("/", 1)
+                self.timestamp = self.repo_path.split("/")[-1]
+                self.credentials = response["creds"]
+                self.s3_client = boto3.client("s3",
+                                              aws_access_key_id=self.credentials["AccessKeyId"],
+                                              aws_secret_access_key=self.credentials["SecretAccessKey"],
+                                              aws_session_token=self.credentials["SessionToken"],
+                                              region_name=DEFAULT_REGION
+                                              )
+                sleep(10)  # Wait for the policy to update
+                self.platform_integration_configured = True
+                self.use_s3_integration = True
+            except HTTPError as e:
+                logging.error(f"Failed to get customer assumed role\n{e}")
+                raise e
+            except ClientError as e:
+                logging.error(f"Failed to initiate client with credentials {self.credentials}\n{e}")
+                raise e
+            except JSONDecodeError as e:
+                logging.error(f"Response of {self.integrations_api_url} is not a valid JSON\n{e}")
+                raise e
+
+        self.get_id_mapping()
+
+        self.platform_integration_configured = True
 
     def get_s3_role(self, bc_api_key, repo_id):
-        request = http.request("POST", self.integrations_api_url, body=json.dumps({"repoId": repo_id}),
+        request = self.http.request("POST", self.integrations_api_url, body=json.dumps({"repoId": repo_id}),
                                headers={"Authorization": bc_api_key, "Content-Type": "application/json"})
         response = json.loads(request.data.decode("utf8"))
         while ('Message' in response or 'message' in response):
@@ -103,7 +144,7 @@ class BcPlatformIntegration(object):
                 raise BridgecrewAuthError()
             if 'message' in response and "cannot be found" in response['message']:
                 self.loading_output("creating role")
-                request = http.request("POST", self.integrations_api_url, body=json.dumps({"repoId": repo_id}),
+                request = self.http.request("POST", self.integrations_api_url, body=json.dumps({"repoId": repo_id}),
                                        headers={"Authorization": bc_api_key, "Content-Type": "application/json"})
                 response = json.loads(request.data.decode("utf8"))
 
@@ -112,16 +153,20 @@ class BcPlatformIntegration(object):
 
     def is_integration_configured(self):
         """
-        Checks if Bridgecrew integration is fully configured.
+        Checks if Bridgecrew integration is fully configured based in input params.
         :return: True if the integration is configured, False otherwise
         """
-        return all([self.repo_path, self.credentials, self.s3_client])
+        return self.platform_integration_configured
 
     def persist_repository(self, root_dir):
         """
         Persist the repository found on root_dir path to Bridgecrew's platform
         :param root_dir: Absolute path of the directory containing the repository root level
         """
+
+        if not self.use_s3_integration:
+            return
+
         for root_path, d_names, f_names in os.walk(root_dir):
             for file_path in f_names:
                 _, file_extension = os.path.splitext(file_path)
@@ -135,6 +180,9 @@ class BcPlatformIntegration(object):
         Persist checkov's scan result into bridgecrew's platform.
         :param scan_reports: List of checkov scan reports
         """
+        if not self.use_s3_integration:
+            return
+
         self.scan_reports = scan_reports
         reduced_scan_reports = reduce_scan_reports(scan_reports)
         checks_metadata_paths = enrich_and_persist_checks_metadata(scan_reports, self.s3_client, self.bucket,
@@ -147,12 +195,25 @@ class BcPlatformIntegration(object):
         :param branch: branch to be persisted
         Finalize the repository's scanning in bridgecrew's platform.
         """
+        if not self.use_s3_integration:
+            return
+
         request = None
         try:
-            request = http.request("PUT", f"{self.integrations_api_url}?source={self.bc_source}",
-                                   body=json.dumps({"path": self.repo_path, "branch": branch}),
-                                   headers={"Authorization": self.bc_api_key, "Content-Type": "application/json"})
+
+            request = self.http.request("PUT", f"{self.integrations_api_url}?source={self.bc_source}",
+                                   body=json.dumps({"path": self.repo_path, "branch": branch, "to_branch": BC_TO_BRANCH,
+                                                    "pr_id": BC_PR_ID, "pr_url": BC_PR_URL,
+                                                    "commit_hash": BC_COMMIT_HASH, "commit_url": BC_COMMIT_URL,
+                                                    "author": BC_AUTHOR_NAME, "author_url": BC_AUTHOR_URL,
+                                                    "run_id": BC_RUN_ID, "run_url": BC_RUN_URL,
+                                                    "repository_url": BC_REPOSITORY_URL}),
+                                   headers={"Authorization": self.bc_api_key, "Content-Type": "application/json",
+                                            'x-api-client': self.bc_source, 'x-api-checkov-version': checkov_version
+                                            })
             response = json.loads(request.data.decode("utf8"))
+            url = response.get("url", None)
+            return url
         except HTTPError as e:
             logging.error(f"Failed to commit repository {self.repo_path}\n{e}")
             raise e
@@ -168,7 +229,7 @@ class BcPlatformIntegration(object):
     def _persist_file(self, full_file_path, relative_file_path):
         tries = 4
         curr_try = 0
-        file_object_key = os.path.join(self.repo_path, relative_file_path)
+        file_object_key = os.path.join(self.repo_path, relative_file_path).replace("\\", "/")
         while curr_try < tries:
             try:
                 self.s3_client.upload_file(full_file_path, self.bucket, file_object_key)
@@ -197,12 +258,22 @@ class BcPlatformIntegration(object):
             self.get_checkov_mapping_metadata()
         return self.bc_id_mapping
 
+    def get_ckv_to_bc_id_mapping(self) -> dict:
+        if not self.ckv_to_bc_id_mapping:
+            self.get_checkov_mapping_metadata()
+        return self.ckv_to_bc_id_mapping
+
     def get_checkov_mapping_metadata(self) -> dict:
+        BC_SKIP_MAPPING = os.getenv("BC_SKIP_MAPPING","FALSE")
+        if BC_SKIP_MAPPING == "TRUE":
+            logging.debug(f"Skipped mapping API call")
+            return {}
         try:
-            request = http.request("GET", self.guidelines_api_url)
+            request = self.http.request("GET", self.guidelines_api_url)
             response = json.loads(request.data.decode("utf8"))
             self.guidelines = response["guidelines"]
             self.bc_id_mapping = response.get("idMapping")
+            self.ckv_to_bc_id_mapping = {ckv_id: bc_id for (bc_id, ckv_id) in self.bc_id_mapping.items()}
             logging.debug(f"Got checkov mappings from Bridgecrew BE")
         except Exception as e:
             logging.debug(f"Failed to get the guidelines from {self.guidelines_api_url}, error:\n{e}")
@@ -228,15 +299,19 @@ class BcPlatformIntegration(object):
                     self.bc_api_key = bc_api_token
                     if response.status_code == 200:
                         print('\n Saving API key to {}'.format(bridgecrew_file))
-                        print(Style.BRIGHT + colored("\n Checkov Dashboard configured, opening https://bridgecrew.cloud, check your inbox for login details! \n", 'blue', attrs=['bold']))
+                        print(Style.BRIGHT + colored(
+                            "\n Checkov Dashboard configured, opening https://bridgecrew.cloud, check your inbox for login details! \n",
+                            'blue', attrs=['bold']))
                         persist_key(self.bc_api_key)
                     else:
                         print(
                             Style.BRIGHT + colored("\nCould not create account, please try again on your next scan! \n",
                                                    'red', attrs=['bold']) + Style.RESET_ALL)
-                    webbrowser.open("https://bridgecrew.cloud/?utm_source=cli&utm_medium=organic_oss&utm_campaign=checkov")
+                    webbrowser.open(
+                        "https://bridgecrew.cloud/?utm_source=cli&utm_medium=organic_oss&utm_campaign=checkov")
             else:
-                print("\n To see the Dashboard prompt again, run `checkov` with no arguments \n For Checkov usage, try `checkov --help`")
+                print(
+                    "\n To see the Dashboard prompt again, run `checkov` with no arguments \n For Checkov usage, try `checkov --help`")
         else:
             print("No argument given. Try ` --help` for further information")
 
@@ -250,19 +325,10 @@ class BcPlatformIntegration(object):
                 self._upload_run(args, scan_reports)
 
     def get_repository(self, args):
-        repo_id = "cli_repo/" + path.basename(args.directory[0])
-        valid_repos = 0
-        # Work out git repo name for BC --repo-id from root_folder
-        # for dir in args.directory:
-        #     try:
-        #         repo = Repo(dir)
-        #         git_remote_uri = repo.remotes.origin.url
-        #         git_repo_dict = re.match(r'(https|git)(:\/\/|@)([^\/:]+)[\/:]([^\/:]+)\/(.+).git',
-        #                                  git_remote_uri).group(4, 5)
-        #         repo_id = git_repo_dict[0] + "/" + git_repo_dict[1]
-        #         valid_repos += 1
-        #     except:  # nosec
-        #         pass
+        if BC_FROM_BRANCH:
+            return BC_FROM_BRANCH
+        basename = 'unnamed_repo' if path.basename(args.directory[0]) == '.' else path.basename(args.directory[0])
+        repo_id = "cli_repo/" + basename
         return repo_id
 
     def get_api_token(self, email, org):
@@ -308,7 +374,8 @@ class BcPlatformIntegration(object):
         result = None
         while not valid:
             result = str(
-                input('Organization name (this will create an account with matching identifier): ')).lower().strip()  # nosec
+                input(
+                    'Organization name (this will create an account with matching identifier): ')).lower().strip()  # nosec
             # remove spaces and special characters
             result = ''.join(e for e in result if e.isalnum())
             if result:
